@@ -8,12 +8,23 @@ VERSION = __version__
 
 # our own modern defaults
 DEFAULTS = dict(
+    baseline=None,
     format='colored',
     max_line_length=90,
     plugins={
         'pyflakes': ['+*'],
         'pycodestyle': ['+*'],
     },
+    exceptions={},
+
+    # disabled by flakehell but required by flake8
+    extend_exclude=[],
+    ignore=[],
+    extend_ignore=[],
+    select=[],
+    enable_extensions=[],
+    per_file_ignores=[],
+    statistics=False,
 )
 
 
@@ -31,6 +42,7 @@ class ExitCodes(IntEnum):
     NO_CODES = 23
 
     TOO_MANY_ARGS = 31
+    NOT_ENOUGH_ARGS = 32
 
 
 KNOWN_PLUGINS = [
@@ -64,6 +76,7 @@ KNOWN_PLUGINS = [
     'flake8-variables-names',
     'mccabe',
     'pep8-naming',
+    'pylint',
 
     # built-in in flake8
     'pycodestyle',
