@@ -6,6 +6,8 @@ from ._codes import codes_command
 from ._lint import lint_command
 from ._missed import missed_command
 from ._plugins import plugins_command
+from ._version import version_command
+from ._yesqa import yesqa_command
 
 
 __all__ = [
@@ -17,14 +19,18 @@ __all__ = [
     'lint_command',
     'missed_command',
     'plugins_command',
+    'version_command',
+    'yesqa_command',
 ]
 
 
-COMMANDS = MappingProxyType(dict(
-    baseline=baseline_command,
-    code=code_command,
-    codes=codes_command,
-    lint=lint_command,
-    missed=missed_command,
-    plugins=plugins_command,
-))
+COMMANDS = MappingProxyType({
+    'baseline': baseline_command,
+    'code': code_command,
+    'codes': codes_command,
+    'lint': lint_command,
+    'missed': missed_command,
+    'plugins': plugins_command,
+    'yesqa': yesqa_command,
+    '--version': version_command,
+})
